==> fullts-0.2.2.tgz: package/src/FullTsApp.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { RpcClient } from 'tsrpc-browser';
import * as PropTypes from 'prop-types';
import { BrowserRouter, Switch, Route } from 'react-router-dom';
import FullTsRouteRender from './FullTsRouteRender';
var FullTsApp = /** @class */ (function () {
    function FullTsApp(config) {
        /**
         * params from parse query string
         */
        this.query = {};
        this._apiRequests = {};
        this.config = config;
        this.rpcClient = new RpcClient({
            serverUrl: this.config.serverUrl
        });
    }
    FullTsApp.prototype.callApi = function (ptl, req) {
        var _this = this;
        //TODO ADD TO CONN POOL AND DISPOSE
        var conn = this.rpcClient.callApi(ptl, req);
        var sn = RpcClient.getLastReqSn();
        this._apiRequests[sn] = conn;
        //pop when complete
        conn.always(function () {
            delete _this._apiRequests[sn];
        }).onCancel(function () {
            delete _this._apiRequests[sn];
        });
        return conn;
    };
    FullTsApp.prototype.renderTo = function (domTarget) {
        this._domTarget = domTarget;
        ReactDOM.render(React.createElement(FullTsAppContainer, { app: this }), domTarget);
    };
    FullTsApp.prototype.dispose = function () {
        this._domTarget && ReactDOM.unmountComponentAtNode(this._domTarget);
        this._domTarget = undefined;
        this.cancelAllApiRequest();
    };
    FullTsApp.prototype.cancelAllApiRequest = function () {
        for (var sn in this._apiRequests) {
            if (this._apiRequests.hasOwnProperty(sn)) {
                this._apiRequests[sn].cancel();
            }
        }
    };
    /**
     * 设置页面标题
     * @param title
     */
    FullTsApp.prototype.setTitle = function (title) {
        var titleNode = document.head.querySelector('title');
        if (!titleNode) {
            titleNode = document.createElement('title');
            document.head.appendChild(titleNode);
        }
        titleNode.innerText = title;
    };
    /**
     * 设置SEO用到的Meta信息
     * @param meta
     */
    FullTsApp.prototype.setSeoMeta = function (meta) {
        var keywordsNode = document.head.querySelector('meta[name=keywords]');
        if (meta.keywords && meta.keywords.length) {
            if (!keywordsNode) {
                keywordsNode = document.createElement('meta');
                keywordsNode.name = 'keywords';
                document.head.appendChild(keywordsNode);
            }
            keywordsNode.content = meta.keywords.join();
        }
        else {
            keywordsNode && keywordsNode.remove();
        }
        var descNode = document.head.querySelector('meta[name=description]');
        if (meta.description) {
            if (!descNode) {
                descNode = document.createElement('meta');
                descNode.name = 'description';
                document.head.appendChild(descNode);
            }
            descNode.content = meta.description;
        }
        else {
            descNode && descNode.remove();
        }
    };
    return FullTsApp;
}());
export default FullTsApp;
var FullTsAppContainer = /** @class */ (function (_super) {
    __extends(FullTsAppContainer, _super);
    function FullTsAppContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FullTsAppContainer.prototype.getChildContext = function () {
        return {
            fullTsApp: this.props.app
        };
    };
    FullTsAppContainer.prototype.render = function () {
        var _this = this;
        return (React.createElement(BrowserRouter, null,
            React.createElement(Switch, null, this.props.app.config.routes.map(function (v, i) {
                return React.createElement(Route, { key: i, path: v.path, exact: true, render: function (props) {
                        var prevLocation = _this.props.app.location;
                        var prevParams = _this.props.app.params;
                        var prevQuery = _this.props.app.query;
                        _this.props.app.history = props.history;
                        _this.props.app.match = props.match;
                        _this.props.app.location = props.location;
                        _this.props.app.params = props.match.params;
                        _this.props.app.query = _this.parseQueryString(props.location.search);
                        //event
                        _this.props.app.config.onRouteChange && _this.props.app.config.onRouteChange({
                            prevLocation: prevLocation,
                            prevParams: prevParams,
                            prevQuery: prevQuery,
                            nextLocation: _this.props.app.location,
                            nextParams: _this.props.app.params,
                            nextQuery: _this.props.app.query
                        });
                        return React.createElement(FullTsRouteRender, { route: v, routeProps: props });
                    } });
            }))));
    };
    FullTsAppContainer.prototype.parseQueryString = function (search) {
        if (!search) {
            return {};
        }
        var paramStrs = search.replace(/^\?/, '').split('&');
        var output = {};
        for (var _i = 0, paramStrs_1 = paramStrs; _i < paramStrs_1.length; _i++) {
            var str = paramStrs_1[_i];
            var equalPos = str.indexOf('=');
            if (equalPos > -1) {
                output[str.slice(0, equalPos)] = decodeURIComponent(str.slice(equalPos + 1));
            }
            else {
                output[str] = '';
            }
        }
        return output;
    };
    FullTsAppContainer.childContextTypes = {
        fullTsApp: PropTypes.instanceOf(FullTsApp)
    };
    return FullTsAppContainer;
}(React.Component));

==> fullts-0.3.5.tgz: package/src/FullTsApp.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { RpcClient } from 'tsrpc-browser';
import * as PropTypes from 'prop-types';
import { BrowserRouter } from 'react-router-dom';
import FullTsRouteSwitch from './FullTsRouteSwitch';
var FullTsApp = /** @class */ (function () {
    function FullTsApp(config) {
        /**
         * params from parse query string
         */
        this.query = {};
        this._apiRequests = {};
        this.config = config;
        this.rpcClient = new RpcClient({
            serverUrl: this.config.serverUrl
        });
    }
    FullTsApp.prototype.callApi = function (ptl, req) {
        var _this = this;
        //TODO ADD TO CONN POOL AND DISPOSE
        var conn = this.rpcClient.callApi(ptl, req);
        var sn = RpcClient.getLastReqSn();
        this._apiRequests[sn] = conn;
        //pop when complete
        conn.always(function () {
            delete _this._apiRequests[sn];
        }).onCancel(function () {
            delete _this._apiRequests[sn];
        });
        return conn;
    };
    FullTsApp.prototype.renderTo = function (domTarget) {
        this._domTarget = domTarget;
        ReactDOM.render(React.createElement(FullTsAppContainer, { app: this }), domTarget);
    };
    FullTsApp.prototype.dispose = function () {
        this._domTarget && ReactDOM.unmountComponentAtNode(this._domTarget);
        this._domTarget = undefined;
        this.cancelAllApiRequest();
    };
    FullTsApp.prototype.cancelAllApiRequest = function () {
        for (var sn in this._apiRequests) {
            if (this._apiRequests.hasOwnProperty(sn)) {
                this._apiRequests[sn].cancel();
            }
        }
    };
    /**
     * 设置页面标题
     * @param title
     */
    FullTsApp.prototype.setTitle = function (title) {
        var titleNode = document.head.querySelector('title');
        if (!titleNode) {
            titleNode = document.createElement('title');
            document.head.appendChild(titleNode);
        }
        titleNode.innerText = title;
    };
    /**
     * 设置SEO用到的Meta信息
     * @param meta
     */
    FullTsApp.prototype.setSeoMeta = function (meta) {
        var keywordsNode = document.head.querySelector('meta[name=keywords]');
        if (meta.keywords && meta.keywords.length) {
            if (!keywordsNode) {
                keywordsNode = document.createElement('meta');
                keywordsNode.name = 'keywords';
                document.head.appendChild(keywordsNode);
            }
            keywordsNode.content = meta.keywords.join();
        }
        else {
            keywordsNode && keywordsNode.remove();
        }
        var descNode = document.head.querySelector('meta[name=description]');
        if (meta.description) {
            if (!descNode) {
                descNode = document.createElement('meta');
                descNode.name = 'description';
                document.head.appendChild(descNode);
            }
            descNode.content = meta.description;
        }
        else {
            descNode && descNode.remove();
        }
    };
    return FullTsApp;
}());
export default FullTsApp;
var FullTsAppContainer = /** @class */ (function (_super) {
    __extends(FullTsAppContainer, _super);
    function FullTsAppContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FullTsAppContainer.prototype.getChildContext = function () {
        return {
            fullTsApp: this.props.app
        };
    };
    FullTsAppContainer.prototype.render = function () {
        return (React.createElement(BrowserRouter, null,
            React.createElement(FullTsRouteSwitch, { routes: this.props.app.config.routes, app: this.props.app })));
    };
    FullTsAppContainer.childContextTypes = {
        fullTsApp: PropTypes.instanceOf(FullTsApp)
    };
    return FullTsAppContainer;
}(React.Component));
